 //-*- Mode: C++ -*-
#ifndef _TEOPP_H_
#define _TEOPP_H_
/* include teo library */  
/* redefine library version information */
#define TEOPP_LIB_VERSION "TEO++ ver.2.4"

extern "C" {
#include <teo.h>
}

/* define access mode */
#ifndef TEO_AC_NOACCESS
#define TEO_AC_NOACCESS 0
#endif
#ifndef TEO_AC_MEMOTY
#define TEO_AC_MEMORY -1
#endif

// $B4pK\%T%/%;%k%/%i%9(B
class TeoBin;
typedef TEO_UINT8   TeoUint8;
typedef TEO_SINT8   TeoSint8;
typedef TEO_UINT16  TeoUint16;
typedef TEO_SINT16  TeoSint16;
typedef TEO_UINT32  TeoUint32;
typedef TEO_SINT32  TeoSint32;
typedef TEO_FLOAT32 TeoFloat32;
typedef TEO_FLOAT64 TeoFloat64;

/* $B2hA|Am>N%/%i%9(B */
class TeoAnyImage;

/* $B2hA|%/%i%9(B */
template <class ETYPE> class TeoImage;

/* $B2hA|%U%!%$%k%"%/%;%9%/%i%9(B */
class TeoFile;

class TeoError;
#include <teopp/teobin.h>
#include <teopp/teoanyimage.h>
#include <teopp/teoimage.h>
#include <teopp/teosequence.h>
#include <teopp/teofile.h>
#endif
